/********************************************************************
 Software License Agreement:

 The software supplied herewith by Microchip Technology Incorporated
 (the "Company") for its PIC(R) Microcontroller is intended and
 supplied to you, the Company's customer, for use solely and
 exclusively on Microchip PIC Microcontroller products. The
 software is owned by the Company and/or its supplier, and is
 protected under applicable copyright laws. All rights are reserved.
 Any use in violation of the foregoing restrictions may subject the
 user to criminal sanctions under applicable laws, as well as to
 civil liability for the breach of the terms and conditions of this
 license.

 THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
 WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *******************************************************************/

/** INCLUDES *******************************************************/
#include "system.h"
#include "system_config.h"

#include "app_device_cdc_basic.h"
//#include "app_led_usb_status.h"

#include "usb.h"
#include "usb_device.h"
#include "usb_device_cdc.h"


#include <stdlib.h>


/********************************************************************
 * Function:        void main(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        Main program entry point.
 *
 * Note:            None
 *******************************************************************/
MAIN_RETURN main(void)
{
    //SYSTEM_Initialize(SYSTEM_STATE_USB_START);
    // 入出力設定
    ADCON0	=	0b00000001; //A/D converter module is enabled:A/D Idle:Channel 0 (AN0)
    ADCON1  =	0b00001100; //AN0とAN1とAN2がアナログ設定：VDDとVSSが選択
    TRISA   =	0b00000111;//AN0とAN1とAN2を入力設定

    TRISB   =	0b00000000; //出力設定
    TRISC   =	0b00110000;//D-,D+（USB用）RC4とRC5を入力に設定
    TRISD   =	0b00000000;//出力設定
    TRISE   =   0b00000011;         //SW1,2=INPUT LED=OUTPUT
    LATA    =	0b00000000;//ラッチ無し
    LATB    =	0b00000000;
    LATC    =	0b00000000;
    LATD    =	0b00000000;
    LATE    =	0b00000000;

    

    InitInterTimer0();
    PEIE = 0;// 周辺機能割込みの許可
    GIE = 1;// 割込み全体の許可

    ADCON2=0x3C;//ADC:111 = 20 TAD , 100 = FOSC/4
    ADCON2bits.ADFM = 1;//ADC:1 = Right justified

    USBDeviceInit();
    USBDeviceAttach();

    //ADC_SetConfiguration(ADC_CONFIGURATION_DEFAULT);//***変更1（ADピン割り当て確定のため）



    //X0=0;
    //gX1=100;gY1=-50;gZ1=-20;


    
    while(1)
    {

        __delay_ms( 10 ); //20mS
        PORTEbits.RE2=!PORTEbits.RE2;

        if(gX0<gX1)
        {
            gX0 = gX0+1;
            MCx=1;//X移動中
            fOutM=1;
        }
        else
        {
            if(gX0>gX1)
            {
                gX0=gX0-1;
                MCx=1;//X移動中
                fOutM=1;
            }
            else
            {
                MCx=0;//X停止中
            }
        }
        if(gY0<gY1)
        {
            gY0 = gY0+1;
            MCy=2;//Y移動中
            fOutM=1;
        }
        else
        {
            if(gY0>gY1)
            {
                gY0=gY0-1;
                MCy=2;//Y移動中
                fOutM=1;
            }
            else
            {
                MCy=0;//Y停止中
            }
        }
        if(gZ0<gZ1)
        {
            gZ0 = gZ0+1;
            MCz=4;//Z移動中
            fOutM=1;
        }
        else
        {
            if(gZ0>gZ1)
            {
                gZ0=gZ0-1;
                MCz=4;//Z移動中
                fOutM=1;
            }
            else
            {
                MCz=0;//Z停止中
            }
        }


        PORTD=16*CHxy[gY0 % 4]+CHxy[gX0 % 4];
        PORTB=CHz[gZ0 % 4];

        if(fOutM==1 && MCx+MCy+MCz==0)
        {
            fOutM=2;//完了報告
        }
        
            


        
        

      


        SYSTEM_Tasks();

        #if defined(USB_POLLING)
            // Interrupt or polling method.  If using polling, must call
            // this function periodically.  This function will take care
            // of processing and responding to SETUP transactions
            // (such as during the enumeration process when you first
            // plug in).  USB hosts require that USB devices should accept
            // and process SETUP packets in a timely fashion.  Therefore,
            // when using polling, this function should be called
            // regularly (such as once every 1.8ms or faster** [see
            // inline code comments in usb_device.c for explanation when
            // "or faster" applies])  In most cases, the USBDeviceTasks()
            // function does not take very long to execute (ex: <100
            // instruction cycles) before it returns.
            USBDeviceTasks();
        #endif


        /* If the USB device isn't configured yet, we can't really do anything
         * else since we don't have a host to talk to.  So jump back to the
         * top of the while loop. */
        if( USBGetDeviceState() < CONFIGURED_STATE )
        {
            /* Jump back to the top of the while loop. */
            continue;
        }

        /* If we are currently suspended, then we need to see if we need to
         * issue a remote wakeup.  In either case, we shouldn't process any
         * keyboard commands since we aren't currently communicating to the host
         * thus just continue back to the start of the while loop. */
        if( USBIsDeviceSuspended()== true )
        {
            /* Jump back to the top of the while loop. */
            continue;
        }

        //Application specific tasks
        //APP_DeviceCDCBasicDemoTasks();
        MyCDCBasicTasks();

    }//end while
}//end main




bool USER_USB_CALLBACK_EVENT_HANDLER(USB_EVENT event, void *pdata, uint16_t size)
{
    switch( (int) event )
    {
        case EVENT_TRANSFER:
            break;

        case EVENT_SOF:
            /* We are using the SOF as a timer to time the LED indicator.  Call
             * the LED update function here. */
            break;

        case EVENT_SUSPEND:
            /* Update the LED status for the suspend event. */
            break;

        case EVENT_RESUME:
            /* Update the LED status for the resume event. */
            break;

        case EVENT_CONFIGURED:
            /* When the device is configured, we can (re)initialize the 
             * demo code. */
            APP_DeviceCDCBasicDemoInitialize();
            break;

        case EVENT_SET_DESCRIPTOR:
            break;

        case EVENT_EP0_REQUEST:
            /* We have received a non-standard USB request.  The HID driver
             * needs to check to see if the request was for it. */
            USBCheckCDCRequest();
            break;

        case EVENT_BUS_ERROR:
            break;

        case EVENT_TRANSFER_TERMINATED:
            break;

        default:
            break;
    }
    return true;
}

/*******************************************************************************
 End of File
*/
